@@ -1,7 +1,7 @@
-# --------------------------------------------------- #
+# -------------------------------------------------------------- #
 # Author: Marius D. PASCARIU
-# Last update: Sun May 02 17:37:09 2021
-# --------------------------------------------------- #
+# Last Update: Mon Jan 15 16:54:54 2024
+# -------------------------------------------------------------- #
 remove(list = ls())
 
 # Wrong index
@@ -17,17 +17,18 @@ expect_error(ReadJMD(what = "Dx",
                      interval = "1x50"))
 
 # Wrong interval for the index
-expect_error(ReadJMD(what = "Ex_lexis",
+expect_message(ReadJMD(what = "Ex_lexis",
                      regions = "Japan",
                      interval = "1x1"))
 
-expect_error(ReadJMD(what = "e0",
+expect_message(ReadJMD(what = "e0",
                      regions = "Japan",
                      interval = "5x1"))
 
-expect_error(ReadJMD(what = "LT_f",
-                     regions = "Kyoto",
-                     interval = "1x1"))
+# remove test since the case is now valid and available in the database.
+# expect_error(ReadJMD(what = "LT_f",
+#                      regions = "Kyoto",
+#                      interval = "1x1"))
 
 expect_output(
   print(JMD_sample)
